@@ -20,8 +20,8 @@
  * @author Sam Lang, Sam Meder
  *
  * $RCSfile: globus_gsi_cred_handle.c,v $
- * $Revision: 1.38.4.1 $
- * $Date: 2010/02/19 21:18:49 $
+ * $Revision: 1.38.4.2 $
+ * $Date: 2010/07/02 19:09:43 $
  */
 #endif
 
@@ -1838,7 +1838,7 @@ globus_gsi_cred_verify_cert_chain(
          * in the chain to be CA cert and throws invalid CA error
          */ 
 
-        #if (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
+        #if defined(X509_V_FLAG_ALLOW_PROXY_CERTS)
 	X509_STORE_CTX_set_flags(
                         store_context, X509_V_FLAG_ALLOW_PROXY_CERTS);
         #endif
