@@ -20,8 +20,8 @@
  * @author Sam Lang, Sam Meder
  * 
  * $RCSfile: globus_gsi_credential.c,v $
- * $Revision: 1.44 $
- * $Date: 2008/11/12 17:13:03 $
+ * $Revision: 1.44.4.1 $
+ * $Date: 2010/06/28 19:17:33 $
  */
 #endif
 
@@ -1862,8 +1862,8 @@ globus_i_gsi_cred_get_proxycertinfo(
 
     *proxycertinfo = NULL;
 
-    pci_NID = OBJ_sn2nid(PROXYCERTINFO_SN);
-    pci_old_NID = OBJ_sn2nid(PROXYCERTINFO_OLD_SN);
+    pci_NID = OBJ_txt2nid(PROXYCERTINFO_OID);
+    pci_old_NID = OBJ_txt2nid(PROXYCERTINFO_OLD_OID);
     if(pci_NID == NID_undef || pci_old_NID == NID_undef)
     {
         GLOBUS_GSI_CRED_ERROR_RESULT(
